@@ -3,9 +3,7 @@ use strict;
 
 use Carp qw(croak);
 
-use vars qw( $VERSION );
-
-$VERSION = '1.001';
+our $VERSION = '1.005';
 
 sub TIESCALAR {
 	my $class = shift;
@@ -39,6 +37,8 @@ sub STORE {
 
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 Tie::BoundedInteger - Limit the magnitude of a number in a scalar
@@ -54,7 +54,8 @@ Tie::BoundedInteger - Limit the magnitude of a number in a scalar
 =head1 DESCRIPTION
 
 You use C<Tie::BoundedInteger> limits the magnitude of a scalar by
-using the C<tie> mechanism.
+using the C<tie> mechanism. This is mostly a demonstration module that
+shows how C<tie> works.
 
 =head1 SOURCE AVAILABILITY
 
@@ -68,8 +69,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2005-2013, brian d foy, All rights reserved
-
-This software is available under the same terms as perl.
+Copyright © 2005-2018, brian d foy <bdfoy@cpan.org>. All rights reserved.
+This software is available under the terms of the Artistic License 2.0.
 
 
